package com.yanzuoguang.mq.service;


import com.rabbitmq.client.Channel;
import com.yanzuoguang.mq.vo.MessageVo;
import org.springframework.amqp.core.Message;

import java.util.List;

/**
 * 发送消息服务
 */
public interface MessageService {

    /**
     * 打上批次,并且所有消息延迟一定时间处理，增加处理次数1次
     *
     * @param batchId 批次编号
     * @param size    消费条数
     * @return 批次数据
     */
    List<MessageVo> updateBatch(String batchId, int size);

    /**
     * 发送消息
     *
     * @param req 发送消息
     * @return 发送结果
     */
    String send(MessageVo req);

    /**
     * 发送下条消息
     *
     * @param messageVo 需要再次发送的消息
     * @return 发送结果
     */
    String nextSend(MessageVo messageVo);

    /**
     * 消息发送成功
     *
     * @param id
     */
    String onSuccess(String id);

    /**
     * 消息发送失败
     *
     * @param messageVo
     */
    String onError(MessageVo messageVo);

    /**
     * 消息收到确认
     *
     * @param message 收到的消息
     * @param channel 　收到的通道
     */
    void basicAck(Message message, Channel channel);
}
